==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/IO/HSetPosn.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_IO_46hSetPosnC_35	((void*)startLabel+12)
#define CT_v220	((void*)startLabel+44)
#define F0_IO_46hSetPosnC_35	((void*)startLabel+52)
#define FN_IO_46hSetPosnC	((void*)startLabel+64)
#define CT_v222	((void*)startLabel+88)
#define CF_IO_46hSetPosnC	((void*)startLabel+96)
#define CT_v227	((void*)startLabel+160)
#define FN_LAMBDA217	((void*)startLabel+200)
#define v228	((void*)startLabel+223)
#define CT_v231	((void*)startLabel+252)
#define F0_LAMBDA217	((void*)startLabel+260)
#define FN_LAMBDA216	((void*)startLabel+292)
#define CT_v233	((void*)startLabel+336)
#define F0_LAMBDA216	((void*)startLabel+344)
#define FN_LAMBDA215	((void*)startLabel+364)
#define CT_v236	((void*)startLabel+396)
#define CF_LAMBDA215	((void*)startLabel+404)
#define ST_v225	((void*)startLabel+408)
#define ST_v230	((void*)startLabel+420)
#define ST_v232	((void*)startLabel+438)
#define ST_v234	((void*)startLabel+456)
#define ST_v221	((void*)startLabel+474)
#define ST_v219	((void*)startLabel+487)
#define ST_v235	((void*)startLabel+501)
extern Node TM_IO[];
void FR_IO_46hSetPosnC_35(void);
extern Node TM_IO[];
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node TM_IO[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_IO[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node TMSUB_IO[];
extern Node FN_NHC_46FFI_46throwIOError[];
extern Node TMSUB_IO[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v220)
,	/* FN_IO_46hSetPosnC_35: (byte 0) */
  useLabel(TM_IO)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_IO_46hSetPosnC_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v219)
,	/* CT_v220: (byte 0) */
  HW(0,2)
, 0
,	/* F0_IO_46hSetPosnC_35: (byte 0) */
  CAPTAG(useLabel(FN_IO_46hSetPosnC_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v222)
,	/* FN_IO_46hSetPosnC: (byte 0) */
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v221)
,	/* CT_v222: (byte 0) */
  HW(2,0)
, 0
,	/* CF_IO_46hSetPosnC: (byte 0) */
  VAPTAG(useLabel(FN_IO_46hSetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_IO_46hSetPosnC_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v227)
,};
Node FN_IO_46hSetPosn[] = {
  useLabel(TM_IO)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_OFF_N1,2,HEAP_P1,0)
, bytes2word(HEAP_I1,HEAP_CVAL_I5,HEAP_P1,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(7,HEAP_OFF_N1,4,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 130001
, useLabel(ST_v225)
,	/* CT_v227: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_IO_46hSetPosn[] = {
  CAPTAG(useLabel(FN_IO_46hSetPosn),1)
, VAPTAG(useLabel(FN_IO_46hSetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA217),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v231)
,	/* FN_LAMBDA217: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDSTACK_I16,PUSH_INT_P1,0,PUSH_ZAP_ARG_I2)
, bytes2word(EVAL,NEEDHEAP_I32,NE_W,JUMPFALSE)
, bytes2word(11,0,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,PUSH_HEAP,HEAP_CVAL_I4,HEAP_CVAL_I5)
,	/* v228: (byte 3) */
  bytes2word(HEAP_OFF_N1,4,RETURN_EVAL,HEAP_CVAL_IN3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,0,0)
, 140010
, useLabel(ST_v230)
,	/* CT_v231: (byte 0) */
  HW(4,2)
, 0
,	/* F0_LAMBDA217: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA217),2)
, CAPTAG(useLabel(FN_LAMBDA216),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v233)
,	/* FN_LAMBDA216: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_CVAL_N1)
, bytes2word(4,HEAP_ARG,1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,5,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(1,1,0)
, CONSTR(0,0,0)
, 160018
, useLabel(ST_v232)
,	/* CT_v233: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA216: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA216),2)
, VAPTAG(useLabel(FN_LAMBDA215))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v236)
,	/* FN_LAMBDA215: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v235)
, 170022
, useLabel(ST_v234)
,	/* CT_v236: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA215: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA215))
,	/* ST_v225: (byte 0) */
  bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
,	/* ST_v230: (byte 4) */
  bytes2word(111,115,110,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,52,58,49)
,	/* ST_v232: (byte 2) */
  bytes2word(48,0,73,79)
, bytes2word(46,104,83,101)
, bytes2word(116,80,111,115)
, bytes2word(110,58,49,54)
,	/* ST_v234: (byte 4) */
  bytes2word(58,49,56,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,55,58,50)
,	/* ST_v221: (byte 2) */
  bytes2word(50,0,73,79)
, bytes2word(46,104,83,101)
, bytes2word(116,80,111,115)
,	/* ST_v219: (byte 3) */
  bytes2word(110,67,0,73)
, bytes2word(79,46,104,83)
, bytes2word(101,116,80,111)
, bytes2word(115,110,67,35)
,	/* ST_v235: (byte 1) */
  bytes2word(0,104,83,101)
, bytes2word(116,80,111,115)
, bytes2word(110,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hSetPosnC" IO.hSetPosnC# 2 :: FFI.ForeignObj -> FFI.ForeignPtr -> Prelude.Int */
extern HsInt hSetPosnC(void*,void*);
#ifdef PROFILE
static SInfo pf_hSetPosnC = {"IO","IO.hSetPosnC#","Prelude.Int"};
#endif
C_HEADER(FR_IO_46hSetPosnC_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  void* arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hSetPosnC(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hSetPosnC);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/IO/HSetPosn.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_IO_46hSetPosnC_35	((void*)startLabel+12)
#define CT_v223	((void*)startLabel+44)
#define F0_IO_46hSetPosnC_35	((void*)startLabel+52)
#define FN_IO_46hSetPosnC	((void*)startLabel+64)
#define CT_v225	((void*)startLabel+88)
#define CF_IO_46hSetPosnC	((void*)startLabel+96)
#define CT_v230	((void*)startLabel+160)
#define FN_LAMBDA220	((void*)startLabel+200)
#define v231	((void*)startLabel+223)
#define CT_v234	((void*)startLabel+252)
#define F0_LAMBDA220	((void*)startLabel+260)
#define FN_LAMBDA219	((void*)startLabel+292)
#define CT_v236	((void*)startLabel+336)
#define F0_LAMBDA219	((void*)startLabel+344)
#define FN_LAMBDA218	((void*)startLabel+364)
#define CT_v239	((void*)startLabel+396)
#define CF_LAMBDA218	((void*)startLabel+404)
#define ST_v228	((void*)startLabel+408)
#define ST_v233	((void*)startLabel+420)
#define ST_v235	((void*)startLabel+444)
#define ST_v237	((void*)startLabel+468)
#define ST_v224	((void*)startLabel+492)
#define ST_v222	((void*)startLabel+505)
#define ST_v238	((void*)startLabel+519)
extern Node TM_IO[];
void FR_IO_46hSetPosnC_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_IO[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node FN_NHC_46FFI_46throwIOError[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v223)
,	/* FN_IO_46hSetPosnC_35: (byte 0) */
  useLabel(TM_IO)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_IO_46hSetPosnC_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 80001
, useLabel(ST_v222)
,	/* CT_v223: (byte 0) */
  HW(0,2)
, 0
,	/* F0_IO_46hSetPosnC_35: (byte 0) */
  CAPTAG(useLabel(FN_IO_46hSetPosnC_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v225)
,	/* FN_IO_46hSetPosnC: (byte 0) */
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 80001
, useLabel(ST_v224)
,	/* CT_v225: (byte 0) */
  HW(2,0)
, 0
,	/* CF_IO_46hSetPosnC: (byte 0) */
  VAPTAG(useLabel(FN_IO_46hSetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_IO_46hSetPosnC_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v230)
,};
Node FN_IO_46hSetPosn[] = {
  useLabel(TM_IO)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_OFF_N1,2,HEAP_P1,0)
, bytes2word(HEAP_I1,HEAP_CVAL_I5,HEAP_P1,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(7,HEAP_OFF_N1,4,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v228)
,	/* CT_v230: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_IO_46hSetPosn[] = {
  CAPTAG(useLabel(FN_IO_46hSetPosn),1)
, VAPTAG(useLabel(FN_IO_46hSetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA220),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v234)
,	/* FN_LAMBDA220: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDSTACK_I16,PUSH_INT_P1,0,PUSH_ZAP_ARG_I2)
, bytes2word(EVAL,NEEDHEAP_I32,NE_W,JUMPFALSE)
, bytes2word(11,0,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,PUSH_HEAP,HEAP_CVAL_I4,HEAP_CVAL_I5)
,	/* v231: (byte 3) */
  bytes2word(HEAP_OFF_N1,4,RETURN_EVAL,HEAP_CVAL_IN3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,0,0)
, 120010
, useLabel(ST_v233)
,	/* CT_v234: (byte 0) */
  HW(4,2)
, 0
,	/* F0_LAMBDA220: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA220),2)
, CAPTAG(useLabel(FN_LAMBDA219),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v236)
,	/* FN_LAMBDA219: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_CVAL_N1)
, bytes2word(4,HEAP_ARG,1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,5,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(1,1,0)
, CONSTR(0,0,0)
, 140018
, useLabel(ST_v235)
,	/* CT_v236: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA219: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA219),2)
, VAPTAG(useLabel(FN_LAMBDA218))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v239)
,	/* FN_LAMBDA218: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v238)
, 150022
, useLabel(ST_v237)
,	/* CT_v239: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA218: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA218))
,	/* ST_v228: (byte 0) */
  bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
,	/* ST_v233: (byte 4) */
  bytes2word(111,115,110,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,50,58,49)
, bytes2word(48,45,49,50)
,	/* ST_v235: (byte 4) */
  bytes2word(58,50,50,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,52,58,49)
, bytes2word(56,45,49,52)
,	/* ST_v237: (byte 4) */
  bytes2word(58,50,53,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,53,58,50)
, bytes2word(50,45,49,53)
,	/* ST_v224: (byte 4) */
  bytes2word(58,51,49,0)
, bytes2word(73,79,46,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,67)
,	/* ST_v222: (byte 1) */
  bytes2word(0,73,79,46)
, bytes2word(104,83,101,116)
, bytes2word(80,111,115,110)
,	/* ST_v238: (byte 3) */
  bytes2word(67,35,0,104)
, bytes2word(83,101,116,80)
, bytes2word(111,115,110,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hSetPosnC" IO.hSetPosnC# 2 :: FFI.ForeignObj -> FFI.ForeignPtr -> Prelude.Int */
extern HsInt hSetPosnC(void*,void*);
#ifdef PROFILE
static SInfo pf_IO_46hSetPosnC_35 = {"IO","IO.hSetPosnC#","Prelude.Int"};
#endif
C_HEADER(FR_IO_46hSetPosnC_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  void* arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hSetPosnC(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_IO_46hSetPosnC_35);
  C_RETURN(nodeptr);
}
